@@ -1,7 +1,10 @@
-ADJ <-function(X,K=K,n=n,J=J){
+ADJ <-function(X){
+  J <- colnames(X)
+  K <- ncol(X)
+  n <- nrow(X)
   ADJ.mat <- matrix(0,nrow=K,ncol=K)
-  ADJ.mat <- t(as.matrix(X))%*%as.matrix(X) / n
+  ADJ.mat <- t(as.matrix(X)) %*% as.matrix(X) / n
   ADJ.mat[!lower.tri(ADJ.mat)] <- NA
   dimnames(ADJ.mat) <- list(J,J)
   return(ADJ.mat)
-}
+}
\ No newline at end of file
