@@ -1,6 +1,10 @@
-DOM <- function(X,K=K,n=n,J=J){
+DOM <- function(X){
+  J <- colnames(X)
+  K <- ncol(X)
+  n <- nrow(X)
   DOM.mat <- matrix(0,nrow=K,ncol=K,dimnames=list(J,J))
   for (i in 1:K) for (j in 1:K) DOM.mat[i,j] <- sum(X[,i] > X[,j])/n
   diag(DOM.mat) <- NA 
   return(DOM.mat)
-}
\ No newline at end of file
+}
+
